************************************************************
	*Title of dofile: WDR2020_chapter2_countryreg_robust.do
	*Authors: Ana Fernandes (afernandes@worldbank.org), Hiau Looi Kee (hlkee@worldbank.org), and Deborah Winkler (dwinkler2@worldbank.org)
	*This version: October 2019
	*This do file generates the country dataset collapsed by decade and runs between-effects regressions to estimate determinants of GVC participation - main results
	*for chapter 2 of the World Development Report 2020.
	*Please cite World Development Report 2020: Trading for Development in the Age of Global Value Chains. Washington, DC: World Bank.				
************************************************************

		
************************************************************
***DETERMINANTS OF GVC PARTICIPATION***
************************************************************
	
clear all
set more off

use "WDR2020_chapter2_countryreg.dta", clear 

egen c=group(iso)
gen decade=(year<2000)
replace decade=2 if year>=2000 & year<2010
replace decade=3 if year>=2010

* generate Pol's suggested measures of endowments using real GDP as denominator
gen lnrkna_GDP=ln(rkna/(exp(lnrgdp)))
gen lnland_GDP=ln(land/(exp(lnrgdp)))
gen lnlowskill_GDP=ln(emp_ls/(exp(lnrgdp)))
gen lnmedhighskill_GDP=ln((emp_hs+emp_ms)/(exp(lnrgdp))) 
gen lnhighskill_GDP=ln((emp_hs)/(exp(lnrgdp))) 

** generate size of manufacturing sector (market size effects for suppliers)
gen lnvamfg=ln(exp(lnngdp)*va_mfg/100)

** generate labor cost - Kee variables 
gen llaborcost=ln((ngdp*labsh/emp))
gen unitlaborcost=rwage/lp_2011
gen lunitlaborcost=ln(unitlaborcost)

** generate distance to 3 GVC hubs
gen lnsumdist=ln(distcapCHN+distcapDEU+distcapUSA)

** generate appreciation rate (>0 is appreciation)
gen ioer=1/oer
by iso: gen appioer=ioer-ioer[_n-1] if year-year[_n-1]==1

* gen logs of trade agreement variables 
gen lnnb_PTApartners=ln(nb_PTApartners)
gen llaborcost_deflated=ln((ngdp*labsh/emp)*(rgdp/ngdp))

egen region2=group(region)
gen high_income=(income=="H")
				 
* some measures collapsed here are not used for baseline regressions in this do-file 
collapse (mean) gvcebsh_EORA gvcebsh_TIVA16 gvcebsh_TIVA18 gvcebsh_WIOD13 gvcebsh_WIOD16 gvcobsh_EORA gvcobsh_TIVA16 gvcobsh_TIVA18 gvcobsh_WIOD13 gvcobsh_WIOD16 iiimports_out_EORA gvcefsh_EORA gvcefsh_TIVA16 gvcefsh_TIVA18 gvcefsh_WIOD13 gvcefsh_WIOD16 gvcofsh_EORA gvcofsh_TIVA16 gvcofsh_TIVA18 gvcofsh_WIOD13  gvcofsh_WIOD16 iiexports_out_EORA gvcesh_EORA gvcesh_TIVA18 gvcesh_TIVA16 gvcesh_WIOD13 gvcesh_WIOD16 gvcosh_EORA gvcosh_TIVA18 gvcosh_TIVA16 gvcosh_WIOD13 gvcosh_WIOD16 tar_wmean_mfg lnfdi_in_flow lnsumdist lnvamfg stability_est rents_resources lnrkna_GDP lnland_GDP lnlowskill_GDP lnmedhighskill_GDP appioer nafta eu mercosur asean lnnb_PTApartners lndepth mis_model1 credit high_income time_im0615 lpi_over_sc f_t_lfpr internet_use english_spoken llaborcost_deflated lngvceb_EORA lngvcef_EORA lngvcob_EORA lngvcof_EORA lngvce_EORA lngvco_EORA lnexports lnimports gvcebsh_agr_alt gvcebsh_comm_alt gvcebsh_mfg_alt gvcebsh_serv_alt gvcefsh_agr_alt gvcefsh_comm_alt gvcefsh_mfg_alt gvcefsh_serv_alt, by(iso decade)

* generate 1-decade lags of GVC determinants to enter GVC participation regressions
foreach x in tar_wmean_mfg lnfdi_in_flow lnsumdist lnvamfg stability_est rents_resources lnrkna_GDP lnland_GDP lnlowskill_GDP lnmedhighskill_GDP appioer nafta eu mercosur asean lnnb_PTApartners lndepth mis_model1 credit high_income time_im0615 lpi_over_sc f_t_lfpr internet_use english_spoken llaborcost_deflated {
sort iso decade
by iso: gen lag`x'=`x'[_n-1] if decade-decade[_n-1]==1
}

* some countries need to be dropped due to problematic values of their EORA GVC participation measures
drop if iso == "mda" | iso == "mus" | iso == "lbr" | iso == "sdn" | iso == "ssd" | iso == "zwe"


tab decade, gen(dedum)
egen c=group(iso)
xtset c



***************** MEASURES OF GVC PARTICIPATION IN SHARES - COEFFICIENTS FOR ALL ROBUSTNESS REGRESSIONS 
gen high_income_dec1t=1 if high_income==1 & decade==1
egen high_income_dec1=max(high_income_dec1t), by(iso)
drop high_income_dec1t
gen lntime_im0615=ln(time_im0615)


***************** MEASURES OF BACKWARD GVC PARTICIPATION 
* baseline (repeated from main table)
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	

* robustness - adding all RTA related variables 
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer lagnafta lageu lagasean lagmerco laglnnb_PTApartners laglndepth dedum* , be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	

* robustness - adding all RTA related variables but dropping tariff FDI and distance due to high correlation
xtreg gvcebsh_EORA lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer lagnafta lageu lagasean lagmerco laglnnb_PTApartners laglndepth dedum* , be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	

* robustness - modifying exchange rate to RER appreciation and to misalignment 
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagmis_model1 dedum* , be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	

* robustness - adding finance 
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer lagcredit dedum* , be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	

* robustness - dropping high-income countries in first decade 
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* if high_income_dec1~=1, be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	

* robustness - adding doing business current year  time_im0615
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer lntime_im0615 if decade==2 , be  
*xtreg gvcebsh_EORA tar_wmean_mfg lnfdi_in_flow lnsumdist stability_est lnvamfg rents_resources lnrkna_GDP lnland_GDP lnlowskill_GDP appioer lntime_im0615 dedum* , be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	

* robustness - adding LPI 
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer lpi_over_sc if decade==2 , be  
*xtreg gvcebsh_EORA tar_wmean_mfg lnfdi_in_flow lnsumdist stability_est lnvamfg rents_resources lnrkna_GDP lnland_GDP lnlowskill_GDP appioer lpi_over_sc dedum* , be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	

* robustness - all contemporaneous variables (time to import included) 
xtreg gvcebsh_EORA tar_wmean_mfg lnfdi_in_flow lnsumdist stability_est lnvamfg rents_resources lnrkna_GDP lnland_GDP lnlowskill_GDP appioer dedum* , be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	

* robustness - adding female labor partic
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer lagf_t_lfpr dedum* , be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	

* robustness - adding internet
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer laginternet_use dedum* , be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	

* robustness - adding english 
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer english_spoken if decade==2 , be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	

* ADDITIONAL EXPERIMENT GVC LEVELS AND TRADE - ADDING WAGES TO THIS ONE BUT DROPPING LABOR ENDOWMENT - KEE INSISTENCE ON APRIL 18
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP  lagappioer lagllaborcost_deflated dedum* , be  
outreg2  using "table_backwardshares_robustness.xls", excel dec(3) append	


***************** MEASURES OF FORWARD GVC PARTICIPATION 
* baseline (repeated from main table)
xtreg gvcefsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	

* robustness - adding all RTA related variables 
xtreg gvcefsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer lagnafta lageu lagasean lagmerco laglnnb_PTApartners laglndepth dedum* , be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	

* robustness - adding all RTA related variables but dropping tariff FDI and distance due to high correlation
xtreg gvcefsh_EORA lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer lagnafta lageu lagasean lagmerco laglnnb_PTApartners laglndepth dedum* , be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	

* robustness - modifying exchange rate to RER appreciation and to misalignment 
xtreg gvcefsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagmis_model1 dedum* , be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	

* robustness - adding finance 
xtreg gvcefsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer lagcredit dedum* , be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	

* robustness - dropping high-income countries in first decade 
xtreg gvcefsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* if high_income_dec1~=1, be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	

* robustness - adding doing business current year  time_im0615
xtreg gvcefsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer lntime_im0615 if decade==2 , be  
*xtreg gvcefsh_EORA tar_wmean_mfg lnfdi_in_flow lnsumdist stability_est lnvamfg rents_resources lnrkna_GDP lnland_GDP lnlowskill_GDP appioer lntime_im0615 dedum* , be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	

* robustness - adding LPI 
xtreg gvcefsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer lpi_over_sc if decade==2 , be  
*xtreg gvcefsh_EORA tar_wmean_mfg lnfdi_in_flow lnsumdist stability_est lnvamfg rents_resources lnrkna_GDP lnland_GDP lnlowskill_GDP appioer lpi_over_sc dedum* , be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	

* robustness - all contemporaneous variables (time to import included) 
xtreg gvcefsh_EORA tar_wmean_mfg lnfdi_in_flow lnsumdist stability_est lnvamfg rents_resources lnrkna_GDP lnland_GDP lnlowskill_GDP appioer dedum* , be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	

* robustness - adding female labor partic
xtreg gvcefsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer lagf_t_lfpr dedum* , be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	

* robustness - adding internet
xtreg gvcefsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer laginternet_use dedum* , be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	

* robustness - adding english
xtreg gvcefsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer english_spoken if decade==2 , be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	

*** ADDITIONAL EXPERIMENTS GVC LEVELS AND TRADE - ADDING WAGES TO THIS ONE BUT DROPPING LABOR ENDOWMENT - KEE INSISTENCE ON APRIL 18
xtreg gvcefsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP  lagappioer lagllaborcost_deflated dedum* , be  
outreg2  using "table_forwardshares_robustness.xls", excel dec(3) append	



***************** MEASURES OF BACKWARD AND FORWARD GVC PARTICIPATION FROM OTHER DATASETS - TIVA & WIOD
* baseline
xtreg gvcebsh_TIVA16 lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_otherdatasets.xls", excel dec(3) append	
xtreg gvcebsh_TIVA18 lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_otherdatasets.xls", excel dec(3) append	
xtreg gvcebsh_WIOD13 lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_otherdatasets.xls", excel dec(3) append	
xtreg gvcebsh_WIOD16 lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_otherdatasets.xls", excel dec(3) append	

* baseline
xtreg gvcefsh_TIVA16 lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_otherdatasets.xls", excel dec(3) append	
xtreg gvcefsh_TIVA18 lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_otherdatasets.xls", excel dec(3) append	
xtreg gvcefsh_WIOD13 lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_otherdatasets.xls", excel dec(3) append	
xtreg gvcefsh_WIOD16 lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_otherdatasets.xls", excel dec(3) append	


***************** MEASURES OF BACKWARD AND FORWARD GVC PARTICIPATION FOR BROAD SECTORS - EORA
* baseline
xtreg gvcebsh_agr_alt lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_sectormeasures.xls", excel dec(3) append	
xtreg gvcebsh_comm_alt lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_sectormeasures.xls", excel dec(3) append	
xtreg gvcebsh_mfg_alt lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_sectormeasures.xls", excel dec(3) append	
xtreg gvcebsh_serv_alt lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_sectormeasures.xls", excel dec(3) append	

* baseline
xtreg gvcefsh_agr_alt lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_sectormeasures.xls", excel dec(3) append	
xtreg gvcefsh_comm_alt lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_sectormeasures.xls", excel dec(3) append	
xtreg gvcefsh_mfg_alt lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_sectormeasures.xls", excel dec(3) append	
xtreg gvcefsh_serv_alt lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
outreg2  using "table_backwardforwardshares_sectormeasures.xls", excel dec(3) append	


*****************  SUMMARY STATISTICS AND CORRELATIONS FOR WORKING PAPER 
xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer dedum* , be  
gen a=1 if e(sample)
* basic variables first
tabstat gvcebsh_EORA gvcefsh_EORA laglnlowskill_GDP lagrents_resources laglnland_GDP laglnrkna_GDP lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg  lagappioer if a==1, stats(N mean median sd)

* robustness variables next
tabstat lagnafta lageu lagasean lagmerco laglnnb_PTApartners laglndepth lagmis_model1 lagcredit lntime_im0615 lpi_over_sc laginternet_use  lagf_t_lfpr lagllaborcost_deflated if a==1, stats(N mean median sd)

xtreg gvcebsh_EORA lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg lagrents_resources laglnrkna_GDP laglnland_GDP laglnlowskill_GDP lagappioer english_spoken if decade==2 , be  
gen b=1 if e(sample)
tabstat english_spoken if b==1, stats(N mean median sd)

* correlations among determinants 
pwcorr laglnlowskill_GDP lagrents_resources laglnland_GDP laglnrkna_GDP lagtar_wmean_mfg laglnfdi_in_flow lnsumdist lagstability_est laglnvamfg  lagappioer lagnafta lageu lagasean lagmerco laglnnb_PTApartners laglndepth lagmis_model1 lagcredit lntime_im0615 lpi_over_sc laginternet_use english_spoken lagf_t_lfpr lagllaborcost_deflated if a==1, star(0.05)





