************************************************************
	*Title of dofile: WDR2020_chapter2_countrysectorreg_main.do 
	*Authors: Ana Fernandes (afernandes@worldbank.org), Hiau Looi Kee (hlkee@worldbank.org), and Deborah Winkler (dwinkler2@worldbank.org)
	*This version: October 2019
	*This do file uses the country-sector dataset to run regressions to estimate determinants of GVC participation LEVELS at country-sector level - main results and robustness results (all based on EORA data)
	*for chapter 2 of the World Development Report 2020.
	*Please cite World Development Report 2020: Trading for Development in the Age of Global Value Chains. Washington, DC: World Bank.				
************************************************************


	
************************************************************
***DETERMINANTS OF GVC PARTICIPATION***
************************************************************
	
clear all
set more off	

use "WDR2020_chapter2_countrysectorreg.dta" 


rename iso3_o iso
* some countries need to be dropped due to problematic values of their EORA GVC participation measures
drop if iso == "mda" | iso == "mus" | iso == "lbr" | iso == "sdn" | iso == "ssd" | iso == "zwe"


*** DEFINING INTERACTION TERMS TO INCLUDE IN COMPARATIVE ADVANTAGE NUNN-TYPE REGRESSIONS

* BASELINE CRUCIAL INTERACTION TERMS (A LA NUNN): CAPITAL SKILL INSTITUTIONAL QUALITY NATURAL RESOURCES
gen KL_Kintens_v1=ln(rkna/emp)*K_L_US

gen skill_skillintens_v1=empsh_hs*Lsk_Lunsk_US

gen natresource_intens=(indcode==6 | indcode==7 | indcode==8) /* defining Braun measure for EORA industries */
gen resources_resourceintens_v1=ln((rents_resources*ngdp)/emp)*natresource_intens

gen instquality_contractintens_v1=ruleoflaw_est*frac_cons_diff

* ADDITIONAL INTERACTION TERM: INTERNET
gen medhightech=(tech_unido=="medhigh")
replace medhightech=. if tech_unido==""
gen internet_techn=internet_use*medhightech 

*** trade-weighted measures output / market access / inputs
gen ltariff2=ln(1+(weighted_tariff_imports/100)) /* tariff on own output */
gen ltariff_market=ln(1+(weighted_tariff_exports /100)) /* note that no 2 is added at end of this tariff name because this variable was used in previous experiments */
gen ltariff_inputsBECUSA2=ln(1+(ww_tariff_inter_usa/100))

*** GVC participation in levels and regular exports 
* Michele Mancini's corrected measures   
*lngvceb (backward measure based on exports, levels in logs) 
*lngvcef (forward measure based on exports, levels in logs)
gen lexports=ln(exp)

egen country_year=group(iso year)
egen sector_year=group(indcode year)



*** defining 3-year lag of determinants 
foreach var of varlist skill_skillintens_v1 KL_Kintens_v1 resources_resourceintens_v1 instquality_contractintens_v1 ltariff2 ltariff_market ltariff_inputsBECUSA2 internet_tech {
sort iso indcode year 
by iso indcode: gen l3`var'=`var'[_n-3]
}
egen iso2=group(iso)


***************** MEASURES OF GVC PARTICIPATION AND REGULAR TRADE BY COUNTRY-SECTOR IN LEVELS - COEFFICIENTS AND BETA COEFFICIENTS SHOWN IN WDR 2020 BOX 2.2 

*** BASELINE
*** specifications use sample with positive GVC forward - so similar sample across specifications 
foreach yvar in lexports lngvcef lngvceb { 
		reghdfe `yvar' l3skill_skillintens_v1 l3KL_Kintens_v1 l3resources_resourceintens_v1 l3instquality_contractintens_v1 l3ltariff2 l3ltariff_market l3ltariff_inputsBECUSA2 if gvcef>0, vce(robust) absorb(country_year indcode) 
		outreg2 using "table_backwardforward_countrysector.xls", excel dec(3) nocons append addtext(Country*year FE,  Yes, Sector FE, Yes) ctitle("`yvar'")	
		esttab using "table_backwardforward_countrysector_betacoeffs.csv", beta append
}

*****************  SUMMARY STATISTICS AND CORRELATIONS FOR WORKING PAPER 
reghdfe lexports l3skill_skillintens_v1 l3KL_Kintens_v1 l3resources_resourceintens_v1 l3instquality_contractintens_v1 l3ltariff2 l3ltariff_market l3ltariff_inputsBECUSA2 if gvcef>0, vce(robust) absorb(country_year indcode) 
gen a=1 if e(sample)
gen capital=ln(rkna/emp) 
gen natresource=ln((rents_resources*ngdp)/emp) 
gen nat_res_int=(indcode==6 | indcode==7 | indcode==8)
foreach var of varlist empsh_hs capital natresource ruleoflaw_est { 
sort iso indcode year 
by iso indcode: gen l3`var'=`var'[_n-3] if a==1
}
tabstat lexports lngvcef lngvceb l3empsh_hs l3capital l3natresource l3ruleoflaw_est if a==1, stats(N mean median sd)
tabstat Lsk_Lunsk_US K_L_US nat_res_int frac_cons_diff  if a==1, stats(N mean median sd)
tabstat l3ltariff2 l3ltariff_inputsBECUSA2 l3ltariff_market if a==1, stats(N mean median sd)
pwcorr l3skill_skillintens_v1 l3KL_Kintens_v1 l3resources_resourceintens_v1 l3instquality_contractintens_v1 l3ltariff2 l3ltariff_inputsBECUSA2 l3ltariff_market  if a==1, star(0.05)

*** specific summary statistics to compute economic magnitudes with country examples
* generate lag for endowments since these are the time-varying variables in the interactions 
tabstat l3empsh_hs l3capital l3natresource l3ruleoflaw_est if a==1, stats(mean median p25 p75 sd N)
summ Lsk_Lunsk_US K_L_US natresource_intens frac_cons_diff if a==1
preserve
collapse (mean) l3empsh_hs l3capital l3natresource l3ruleoflaw_est  if a==1, by(iso year)
gsort -l3empsh_hs
br iso year l3empsh_hs if l3empsh_hs<20.6 & year==2015 /* look for countries below median */
gsort -l3ruleoflaw_est
br iso year l3ruleoflaw_est if l3ruleoflaw_est<-0.122 & year==2015 /* look for countries below median */
restore

*** ROBUSTNESS ADDING INTERNET (need to rerun data generation since dataset was collapsed just above


*** specifications use sample with positive GVC forward - so similar sample across specifications 
foreach yvar in lexports lngvcef lngvceb { 
		reghdfe `yvar' l3skill_skillintens_v1 l3KL_Kintens_v1 l3resources_resourceintens_v1 l3instquality_contractintens_v1 l3ltariff2 l3ltariff_market l3ltariff_inputsBECUSA2 l3internet_tech if gvcef>0, vce(robust) absorb(country_year indcode) 
		outreg2 using "table_backwardforward_countrysector_internet.xls", excel dec(3) nocons append addtext(Country*year FE,  Yes, Sector FE, Yes) ctitle("`yvar'")	
		esttab using "table_backwardforward_countrysector_internet_betacoeffs.csv", beta append
}

*****************  SUMMARY STATISTICS AND CORRELATIONS FOR WORKING PAPER 
reghdfe lexports l3skill_skillintens_v1 l3KL_Kintens_v1 l3resources_resourceintens_v1 l3instquality_contractintens_v1 l3ltariff2 l3ltariff_market l3ltariff_inputsBECUSA2 l3internet_tech if gvcef>0, vce(robust) absorb(country_year indcode) 
gen b=1 if e(sample)
foreach var of varlist internet_use { 
sort iso indcode year 
by iso indcode: gen l3`var'=`var'[_n-3] if b==1
}
tabstat internet_use medhightech  if b==1, stats(N mean median sd) /* only available for 5 EORA sectors */
pwcorr l3skill_skillintens_v1 l3KL_Kintens_v1 l3resources_resourceintens_v1 l3instquality_contractintens_v1 l3ltariff2 l3ltariff_inputsBECUSA2 l3ltariff_market l3internet_tech  if b==1, star(0.05)



















